@@ -270,5 +270,5 @@ def clock(unit):
 __all__ = [
     "text_to_speech", "randcolor", "rgbcolor", "upload_gif", "search_real_usage", "showcursor","count_words", "get_day_name", "get_system_summary","open_web", "rename", "today",
     "save_var", "load_var", "getping", "clock", "mouseX", "mouseY","hidecursor", "shapecursor","run_app", "get_file_size", "generate_password", "google_search", "random_filename",
-    "key", "click", "getcolor", "rc", "ri", "leftclick", "middleclick", "rightclick", "play_mp3", "system", "copy_text", "browser", "speech_to_text", "speak", "to_upper", "list_files"
+    "key", "click", "getcolor", "rc", "ri", "leftclick", "middleclick", "rightclick", "play_mp3", "system", "copy_text", "browser", "speech_to_text", "speak", "to_upper", "list_files", "my_ip"
 ]
